# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventBindRequest(Model):
    """ActivityEventBindRequest.

    All required parameters must be populated in order to send to Azure.

    :param bind_type: Required. Possible values include: 'Group', 'Metric',
     'EvidenceMetric', 'Model', 'GroupModel'
    :type bind_type: str or ~smartdiagnostics_sdk.models.enum
    :param bind_id: Required.
    :type bind_id: str
    """

    _validation = {
        'bind_type': {'required': True},
        'bind_id': {'required': True},
    }

    _attribute_map = {
        'bind_type': {'key': 'BindType', 'type': 'str'},
        'bind_id': {'key': 'BindId', 'type': 'str'},
    }

    def __init__(self, *, bind_type, bind_id: str, **kwargs) -> None:
        super(ActivityEventBindRequest, self).__init__(**kwargs)
        self.bind_type = bind_type
        self.bind_id = bind_id
