# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventSubcategoryResponse(Model):
    """ActivityEventSubcategoryResponse.

    :param id:
    :type id: str
    :param code:
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param location_id:
    :type location_id: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventSubcategoryResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.code = kwargs.get('code', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.location_id = kwargs.get('location_id', None)
