# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraCreateRequest(Model):
    """Request object to create a ThermalCamera and its settings.

    All required parameters must be populated in order to send to Azure.

    :param serial_number: Required. Unique serial number of the camera.
    :type serial_number: long
    :param location_id: Required. The Location/Account ID
    :type location_id: str
    :param settings: Required.
    :type settings:
     ~smartdiagnostics_sdk.models.ThermalCameraSettingsCreateRequest
    """

    _validation = {
        'serial_number': {'required': True},
        'location_id': {'required': True},
        'settings': {'required': True},
    }

    _attribute_map = {
        'serial_number': {'key': 'SerialNumber', 'type': 'long'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'settings': {'key': 'Settings', 'type': 'ThermalCameraSettingsCreateRequest'},
    }

    def __init__(self, **kwargs):
        super(ThermalCameraCreateRequest, self).__init__(**kwargs)
        self.serial_number = kwargs.get('serial_number', None)
        self.location_id = kwargs.get('location_id', None)
        self.settings = kwargs.get('settings', None)
