# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelUpdateRequest(Model):
    """AnalyticsModelUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param is_deprecated: Required.
    :type is_deprecated: bool
    :param triggers:
    :type triggers: list[~smartdiagnostics_sdk.models.TriggerChild]
    """

    _validation = {
        'is_deprecated': {'required': True},
    }

    _attribute_map = {
        'is_deprecated': {'key': 'IsDeprecated', 'type': 'bool'},
        'triggers': {'key': 'Triggers', 'type': '[TriggerChild]'},
    }

    def __init__(self, *, is_deprecated: bool, triggers=None, **kwargs) -> None:
        super(AnalyticsModelUpdateRequest, self).__init__(**kwargs)
        self.is_deprecated = is_deprecated
        self.triggers = triggers
