# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SmartAlarmsRequest(Model):
    """SmartAlarmsRequest.

    :param end_date: The end date of data to calculate smart alarms for.
    :type end_date: datetime
    :param coefficient: The coefficent to calculate SmartAlarm values. Must be
     between 0-5
    :type coefficient: float
    """

    _validation = {
        'coefficient': {'maximum': 5, 'minimum': 0},
    }

    _attribute_map = {
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'coefficient': {'key': 'Coefficient', 'type': 'float'},
    }

    def __init__(self, *, end_date=None, coefficient: float=None, **kwargs) -> None:
        super(SmartAlarmsRequest, self).__init__(**kwargs)
        self.end_date = end_date
        self.coefficient = coefficient
