# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldResponse(Model):
    """ActivityEventFieldResponse.

    :param id:
    :type id: str
    :param code:
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param field_type: Possible values include: 'String', 'Bool', 'Int',
     'Float', 'Status'
    :type field_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'field_type': {'key': 'FieldType', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, code: str=None, name: str=None, description: str=None, field_type=None, **kwargs) -> None:
        super(ActivityEventFieldResponse, self).__init__(**kwargs)
        self.id = id
        self.code = code
        self.name = name
        self.description = description
        self.field_type = field_type
