# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldEntryChild(Model):
    """ActivityEventFieldEntryChild.

    :param field_entry_id:
    :type field_entry_id: str
    :param field_value:
    :type field_value: str
    :param field_id:
    :type field_id: str
    :param field_code:
    :type field_code: str
    :param field_name:
    :type field_name: str
    :param field_type: Possible values include: 'String', 'Bool', 'Int',
     'Float', 'Status'
    :type field_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'field_entry_id': {'key': 'FieldEntryId', 'type': 'str'},
        'field_value': {'key': 'FieldValue', 'type': 'str'},
        'field_id': {'key': 'FieldId', 'type': 'str'},
        'field_code': {'key': 'FieldCode', 'type': 'str'},
        'field_name': {'key': 'FieldName', 'type': 'str'},
        'field_type': {'key': 'FieldType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventFieldEntryChild, self).__init__(**kwargs)
        self.field_entry_id = kwargs.get('field_entry_id', None)
        self.field_value = kwargs.get('field_value', None)
        self.field_id = kwargs.get('field_id', None)
        self.field_code = kwargs.get('field_code', None)
        self.field_name = kwargs.get('field_name', None)
        self.field_type = kwargs.get('field_type', None)
