# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsLogResponse(Model):
    """AnalyticsLogResponse.

    All required parameters must be populated in order to send to Azure.

    :param message: Required.
    :type message: str
    :param date_property: Required.
    :type date_property: datetime
    """

    _validation = {
        'message': {'required': True},
        'date_property': {'required': True},
    }

    _attribute_map = {
        'message': {'key': 'Message', 'type': 'str'},
        'date_property': {'key': 'Date', 'type': 'iso-8601'},
    }

    def __init__(self, *, message: str, date_property, **kwargs) -> None:
        super(AnalyticsLogResponse, self).__init__(**kwargs)
        self.message = message
        self.date_property = date_property
