# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraImageResponse(Model):
    """ThermalCameraImageResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param timestamp: Required.
    :type timestamp: datetime
    :param image: Required.
    :type image: bytearray
    :param thermal_camera_serial_number: Required.
    :type thermal_camera_serial_number: long
    """

    _validation = {
        'id': {'required': True},
        'timestamp': {'required': True},
        'image': {'required': True},
        'thermal_camera_serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'timestamp': {'key': 'Timestamp', 'type': 'iso-8601'},
        'image': {'key': 'Image', 'type': 'bytearray'},
        'thermal_camera_serial_number': {'key': 'ThermalCameraSerialNumber', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(ThermalCameraImageResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.timestamp = kwargs.get('timestamp', None)
        self.image = kwargs.get('image', None)
        self.thermal_camera_serial_number = kwargs.get('thermal_camera_serial_number', None)
