# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventSubcategoryChild(Model):
    """ActivityEventSubcategoryChild.

    :param subcategory_id:
    :type subcategory_id: str
    :param subcategory_code:
    :type subcategory_code: str
    :param subcategory_name:
    :type subcategory_name: str
    """

    _attribute_map = {
        'subcategory_id': {'key': 'SubcategoryId', 'type': 'str'},
        'subcategory_code': {'key': 'SubcategoryCode', 'type': 'str'},
        'subcategory_name': {'key': 'SubcategoryName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventSubcategoryChild, self).__init__(**kwargs)
        self.subcategory_id = kwargs.get('subcategory_id', None)
        self.subcategory_code = kwargs.get('subcategory_code', None)
        self.subcategory_name = kwargs.get('subcategory_name', None)
