# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TokenExchangeResponse(Model):
    """TokenExchangeResponse.

    :param token:
    :type token: str
    """

    _attribute_map = {
        'token': {'key': 'Token', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TokenExchangeResponse, self).__init__(**kwargs)
        self.token = kwargs.get('token', None)
