# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorSensorRoleTypeCodeChild(Model):
    """IndicatorSensorRoleTypeCodeChild.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param sensor_role_type_code: Possible values include: 'Invalid',
     'CurrentPhaseA', 'PeakCurrentPhaseA', 'CurrentPhaseB',
     'PeakCurrentPhaseB', 'CurrentPhaseC', 'PeakCurrentPhaseC',
     'DifferentialPressure', 'Flow', 'Humidity', 'NodeTemperature',
     'NodeVoltage', 'PeakVibration', 'Pressure', 'RmsVibration',
     'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage', 'Temperature',
     'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis', 'Voltage', 'Current',
     'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3', 'AtoDChannel4',
     'AtoDChannel5', 'AtoDChannel6', 'OilTemperature', 'OilHumidity', 'X', 'Y',
     'Z', 'Custom', 'WirelessEfficiency', 'PacketSuccessRate', 'NodeHumidity',
     'BurstSuccessRate'
    :type sensor_role_type_code: str or ~smartdiagnostics_sdk.models.enum
    :ivar sensor_role_type_code_formatted:
    :vartype sensor_role_type_code_formatted: str
    """

    _validation = {
        'sensor_role_type_code_formatted': {'readonly': True},
    }

    _attribute_map = {
        'sensor_role_type_code': {'key': 'SensorRoleTypeCode', 'type': 'str'},
        'sensor_role_type_code_formatted': {'key': 'SensorRoleTypeCodeFormatted', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IndicatorSensorRoleTypeCodeChild, self).__init__(**kwargs)
        self.sensor_role_type_code = kwargs.get('sensor_role_type_code', None)
        self.sensor_role_type_code_formatted = None
