# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryOwnerChild(Model):
    """ActivityEventCategoryOwnerChild.

    :param owner_type: Possible values include: 'Global', 'Application',
     'Account'
    :type owner_type: str or ~smartdiagnostics_sdk.models.enum
    :param owner_id:
    :type owner_id: str
    """

    _attribute_map = {
        'owner_type': {'key': 'OwnerType', 'type': 'str'},
        'owner_id': {'key': 'OwnerId', 'type': 'str'},
    }

    def __init__(self, *, owner_type=None, owner_id: str=None, **kwargs) -> None:
        super(ActivityEventCategoryOwnerChild, self).__init__(**kwargs)
        self.owner_type = owner_type
        self.owner_id = owner_id
