# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationUpdateRequest(Model):
    """BaseStationUpdateRequest.

    :param nickname:
    :type nickname: str
    :param location_id:
    :type location_id: str
    :param release_ring_id:
    :type release_ring_id: str
    :param push_to_stage:
    :type push_to_stage: bool
    """

    _validation = {
        'nickname': {'max_length': 50},
    }

    _attribute_map = {
        'nickname': {'key': 'Nickname', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'release_ring_id': {'key': 'ReleaseRingId', 'type': 'str'},
        'push_to_stage': {'key': 'PushToStage', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BaseStationUpdateRequest, self).__init__(**kwargs)
        self.nickname = kwargs.get('nickname', None)
        self.location_id = kwargs.get('location_id', None)
        self.release_ring_id = kwargs.get('release_ring_id', None)
        self.push_to_stage = kwargs.get('push_to_stage', None)
