# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertAcknowledgementRequest(Model):
    """AlertAcknowledgementRequest.

    All required parameters must be populated in order to send to Azure.

    :param group_ids: Required. IDs of groups for which all of the alerts
     under them should be acknowledged
    :type group_ids: list[str]
    """

    _validation = {
        'group_ids': {'required': True},
    }

    _attribute_map = {
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
    }

    def __init__(self, *, group_ids, **kwargs) -> None:
        super(AlertAcknowledgementRequest, self).__init__(**kwargs)
        self.group_ids = group_ids
