# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventHierarchyGroupRequest(Model):
    """ActivityEventHierarchyGroupRequest.

    All required parameters must be populated in order to send to Azure.

    :param start_date_time: Required.
    :type start_date_time: datetime
    :param end_date_time: Required.
    :type end_date_time: datetime
    :param indicator_ids:
    :type indicator_ids: list[str]
    :param group_ids:
    :type group_ids: list[str]
    :param category_ids:
    :type category_ids: list[int]
    :param activity_line_enabled:
    :type activity_line_enabled: bool
    :param location_id:
    :type location_id: str
    :param title:
    :type title: str
    """

    _validation = {
        'start_date_time': {'required': True},
        'end_date_time': {'required': True},
    }

    _attribute_map = {
        'start_date_time': {'key': 'StartDateTime', 'type': 'iso-8601'},
        'end_date_time': {'key': 'EndDateTime', 'type': 'iso-8601'},
        'indicator_ids': {'key': 'IndicatorIds', 'type': '[str]'},
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
        'category_ids': {'key': 'CategoryIds', 'type': '[int]'},
        'activity_line_enabled': {'key': 'ActivityLineEnabled', 'type': 'bool'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventHierarchyGroupRequest, self).__init__(**kwargs)
        self.start_date_time = kwargs.get('start_date_time', None)
        self.end_date_time = kwargs.get('end_date_time', None)
        self.indicator_ids = kwargs.get('indicator_ids', None)
        self.group_ids = kwargs.get('group_ids', None)
        self.category_ids = kwargs.get('category_ids', None)
        self.activity_line_enabled = kwargs.get('activity_line_enabled', None)
        self.location_id = kwargs.get('location_id', None)
        self.title = kwargs.get('title', None)
