# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldEntryRequest(Model):
    """ActivityEventFieldEntryRequest.

    All required parameters must be populated in order to send to Azure.

    :param field_id:
    :type field_id: str
    :param field_code:
    :type field_code: str
    :param value: Required.
    :type value: str
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'FieldId', 'type': 'str'},
        'field_code': {'key': 'FieldCode', 'type': 'str'},
        'value': {'key': 'Value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventFieldEntryRequest, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.field_code = kwargs.get('field_code', None)
        self.value = kwargs.get('value', None)
