# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventBindChild(Model):
    """ActivityEventBindChild.

    :param bind_id:
    :type bind_id: str
    :param bind_type: Possible values include: 'Group', 'Metric',
     'EvidenceMetric', 'Model', 'GroupModel'
    :type bind_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'bind_id': {'key': 'BindId', 'type': 'str'},
        'bind_type': {'key': 'BindType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventBindChild, self).__init__(**kwargs)
        self.bind_id = kwargs.get('bind_id', None)
        self.bind_type = kwargs.get('bind_type', None)
