# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldValueRequest(Model):
    """ActivityEventFieldValueRequest.

    All required parameters must be populated in order to send to Azure.

    :param value: Required.
    :type value: str
    :param label:
    :type label: str
    :param order:
    :type order: int
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'Value', 'type': 'str'},
        'label': {'key': 'Label', 'type': 'str'},
        'order': {'key': 'Order', 'type': 'int'},
    }

    def __init__(self, *, value: str, label: str=None, order: int=None, **kwargs) -> None:
        super(ActivityEventFieldValueRequest, self).__init__(**kwargs)
        self.value = value
        self.label = label
        self.order = order
