# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryChild(Model):
    """ActivityEventCategoryChild.

    :param category_id:
    :type category_id: int
    :param category_code:
    :type category_code: str
    :param category_name:
    :type category_name: str
    :param category_owner_type: Possible values include: 'Global',
     'Application', 'Account'
    :type category_owner_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'category_code': {'key': 'CategoryCode', 'type': 'str'},
        'category_name': {'key': 'CategoryName', 'type': 'str'},
        'category_owner_type': {'key': 'CategoryOwnerType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventCategoryChild, self).__init__(**kwargs)
        self.category_id = kwargs.get('category_id', None)
        self.category_code = kwargs.get('category_code', None)
        self.category_name = kwargs.get('category_name', None)
        self.category_owner_type = kwargs.get('category_owner_type', None)
