# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorOptionsResponse(Model):
    """IndicatorOptionsResponse.

    :param sensor_role_type_codes:
    :type sensor_role_type_codes:
     list[~smartdiagnostics_sdk.models.IndicatorSensorRoleTypeCodeChild]
    """

    _attribute_map = {
        'sensor_role_type_codes': {'key': 'SensorRoleTypeCodes', 'type': '[IndicatorSensorRoleTypeCodeChild]'},
    }

    def __init__(self, **kwargs):
        super(IndicatorOptionsResponse, self).__init__(**kwargs)
        self.sensor_role_type_codes = kwargs.get('sensor_role_type_codes', None)
