# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MarkerChild(Model):
    """MarkerChild.

    All required parameters must be populated in order to send to Azure.

    :param marker_name:
    :type marker_name: str
    :param marker_show_harmonics: Required.
    :type marker_show_harmonics: bool
    :param marker_show_side_bands: Required.
    :type marker_show_side_bands: bool
    :param marker_show_peaks: Required.
    :type marker_show_peaks: bool
    """

    _validation = {
        'marker_name': {'max_length': 5},
        'marker_show_harmonics': {'required': True},
        'marker_show_side_bands': {'required': True},
        'marker_show_peaks': {'required': True},
    }

    _attribute_map = {
        'marker_name': {'key': 'MarkerName', 'type': 'str'},
        'marker_show_harmonics': {'key': 'MarkerShowHarmonics', 'type': 'bool'},
        'marker_show_side_bands': {'key': 'MarkerShowSideBands', 'type': 'bool'},
        'marker_show_peaks': {'key': 'MarkerShowPeaks', 'type': 'bool'},
    }

    def __init__(self, *, marker_show_harmonics: bool, marker_show_side_bands: bool, marker_show_peaks: bool, marker_name: str=None, **kwargs) -> None:
        super(MarkerChild, self).__init__(**kwargs)
        self.marker_name = marker_name
        self.marker_show_harmonics = marker_show_harmonics
        self.marker_show_side_bands = marker_show_side_bands
        self.marker_show_peaks = marker_show_peaks
