# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AcknowledgedAlertsResponse(Model):
    """AcknowledgedAlertsResponse.

    All required parameters must be populated in order to send to Azure.

    :param alerts_acknowledged: Required. The number of alerts that were
     acknowledged
    :type alerts_acknowledged: int
    """

    _validation = {
        'alerts_acknowledged': {'required': True},
    }

    _attribute_map = {
        'alerts_acknowledged': {'key': 'AlertsAcknowledged', 'type': 'int'},
    }

    def __init__(self, *, alerts_acknowledged: int, **kwargs) -> None:
        super(AcknowledgedAlertsResponse, self).__init__(**kwargs)
        self.alerts_acknowledged = alerts_acknowledged
