# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelRelatedModelChild(Model):
    """AnalyticsModelRelatedModelChild.

    :param related_model_id:
    :type related_model_id: str
    :param related_model_name:
    :type related_model_name: str
    :param related_model_type: Possible values include: 'SMARTIndicator',
     'Classifier'
    :type related_model_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'related_model_id': {'key': 'RelatedModelId', 'type': 'str'},
        'related_model_name': {'key': 'RelatedModelName', 'type': 'str'},
        'related_model_type': {'key': 'RelatedModelType', 'type': 'str'},
    }

    def __init__(self, *, related_model_id: str=None, related_model_name: str=None, related_model_type=None, **kwargs) -> None:
        super(AnalyticsModelRelatedModelChild, self).__init__(**kwargs)
        self.related_model_id = related_model_id
        self.related_model_name = related_model_name
        self.related_model_type = related_model_type
